%global debug_package %{nil}
%global gituser       ytdl-org
%global gitname       youtube-dl
%global foldername    youtube_dl
%global commit        a084c80f7bac9ae343075a97cc0fb2c1c96ade89
%global shortcommit   %(c=%{commit}; echo ${c:0:7})
%global gitcounter    135

Name:           youtube-dl
Version:        2021.12.17.git.%{gitcounter}
Release:        %{shortcommit}%{?dist}
Summary:        A small command-line program to download online videos
License:        Unlicense
URL:            https://github.com/%{gituser}/%{gitname}
Source0:        %{url}/tarball/%{commit}#/%{gituser}-%{name}-%{shortcommit}.tar.gz
# Needed to query completion locations and to make docs
%if 0%{?fedora} <= 40
BuildRequires:  bash-completion
%else
BuildRequires:  bash-completion-devel
%endif
BuildRequires:  fish pandoc
BuildArch:      noarch

%description
Small command-line program to download videos from YouTube and other sites.

%prep
%autosetup -p1 -n %{gituser}-%{gitname}-%{shortcommit}

# Remove files that are installed to the wrong path
sed -i '/%{name}.bash-completion/d' setup.py
sed -i '/%{name}.fish/d' setup.py
sed -i '/README.txt/d' setup.py
# Fix depreciation warning
sed -i '/[wheel]/d' setup.cfg
sed -i '/universal/d' setup.cfg

%{python3} devscripts/bash-completion.py
%{python3} devscripts/fish-completion.py
%{python3} devscripts/zsh-completion.py

# make docs (from Makefile)
MARKDOWN="markdown-smart"

%{python3} devscripts/prepare_manpage.py %{name}.1.temp
pandoc -s -f "$MARKDOWN" -t man %{name}.1.temp -o %{name}.1

mv -f README.md README.md.temp
pandoc -f "$MARKDOWN" -t plain README.md.temp -o README.md

rm -f %{name}.1.temp README.md.temp supportedsites.md
%{python3} devscripts/make_supportedsites.py supportedsites.md

# Remove interpreter shebang from module files.
find %{foldername} -type f -exec sed -i -e '1{/^\#!\/usr\/bin\/env python$/d;};' {} +

%generate_buildrequires
%pyproject_buildrequires -r

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{foldername}

mkdir -p %{buildroot}{$(pkg-config --variable completionsdir bash-completion),$(pkg-config --variable completionsdir fish),%{_datadir}/zsh/site-functions,%{_sysconfdir}}
install -pm644 %{name}.bash-completion %{buildroot}$(pkg-config --variable completionsdir bash-completion)/%{name}
install -pm644 %{name}.fish %{buildroot}$(pkg-config --variable completionsdir fish)/%{name}.fish
install -pm644 %{name}.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

cat > %{buildroot}%{_sysconfdir}/%{name}.conf << EOF
# Default configuration for youtube-dl.

--prefer-free-formats
--hls-prefer-native
EOF

%check

# AUTHORS and LICENSE already in dist-info
%files -f %{pyproject_files}
%doc ChangeLog README.md supportedsites.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/fish/vendor_completions.d/%{name}.fish
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Sun Jun 5 2022 samoht0 <https://copr.fedorainfracloud.org/coprs/samoht0/> git-master
- adopting new Python Packaging Guidelines
- spec and history cleanup
